from netforce.model import Model, fields, get_model
from netforce.utils import get_file_path, get_data_path
from netforce.access import get_active_company

class ClinicSetting(Model):
    _name="clinic.setting"
    _string="Setting"


    _fields={
        "var_k": fields.Float("K"),
        'file': fields.File("File"),
        'levels': fields.One2Many("clinic.setting.level","setting_id","Levels"),
        'products': fields.One2Many("clinic.setting.product","setting_id","Products"),
        'invoice_policies': fields.One2Many("clinic.setting.policy","setting_id","Invoice Policies"),
        'cost_per_case': fields.Float("Cost Per Case"),
        'company_id': fields.Many2One("company", 'Company'),
        'period_id': fields.Many2One("clinic.period","Period"),
        'waiting_approval': fields.Boolean("Waiting Approval"), # HD Case
        'real_time': fields.Boolean("Real Time"), # HD Case
        'patient_type_id': fields.Many2One("clinic.patient.type","Default Type"), # Import payment
        'find_dlz': fields.Boolean("Find Dialyzer After Confirm Visit"), # Visit
        'stock_journal_id': fields.Many2One("stock.journal","Default Journal"),
        'auto_gen': fields.Boolean("Auto Gen") # HD Case
    }

    _defaults={
        "company_id": lambda *a: get_active_company(),
    }

    def onchange_line(self,context={}):
        data=context['data']
        path=context['path']
        line=get_data_path(data,path,parent=True)
        var_a=line['var_a'] or ''
        var_b=line['var_b'] or ''
        op=line['op'] or ''
        line['formular']='%sX%s%s'%(var_a,op,var_b)
        return data

    def onchange_product(self,context={}):
        data=context['data']
        path=context['path']
        line=get_data_path(data,path,parent=True)
        product_id=line['product_id']
        if product_id:
            prod=get_model("product").browse(product_id)
            uom=prod.uom_id
            if not uom:
                uom=get_model("uom").browse(1)
                if not uom:
                    raise Exception("Not found uom 'Unit'")
            line['uom_id']=uom.id
            line['description']=prod.name
            price=prod.sale_price or 0.0
            line['price']=price
            qty=1
            amt=qty*price
            line['amount']=amt
        return data

    def onchange_setting_line(self,context={}):
        data=context['data']
        path=context['path']
        line=get_data_path(data,path,parent=True)
        qty=line['qty'] or 0
        price=line['price'] or 0
        amt=qty*price
        line['amount']=amt
        return data

ClinicSetting.register()
